# TSETMC Api

یک کتابخانه که فعلا این کارها رو میتونه انجام بده:

- دیده‌بان بازار و فیلترنویسی (با دسترسی به تموم بخش‌هایی که در فیلترنویسی معمولی به اونها دسترسی دارید)
- سابقه‌ی یک سهم
- جزئیات یک روز خاص
- سهامداران عمده و همچنین تاریخچه‌ی اونها (همون نموداره که وقتی روشون کلیک میکنی نشون میده)
- بخش شناسه‌ی یک سهم
- تاریخچه‌ی حقیقی حقوقی یک سهم

و بخش‌هایی که هنوز کامل نشده:

- صفحه‌ی اصلی خود سهم (قیمت الان سهم چقدره)
- لیست تمام نماد‌ها (اینو من صفحه‌ای رو پیدا نکردم که همه رو (چه بورس چه فرابورس) رو لیست کرده باشه)

## نحوه‌ی نصب

```shell script
pip3 install tsetmc-api
```

## مثال‌ها

| فایل مثال | توضیح |
|-----------|-------|
| examples/watch.py | کار با دیده‌بان و فیلترنویسی |

## کمک به توسعه

برای کمک در توسعه چندتا کار میتونید انجام بدید:

- نوشتن داکیومنت
- پیشنهاد برای اضافه کردن یک قابلیت خاص با ایجاد issue
- پیاده‌سازی یک قابلیت جدید یا بهبود قابلیت‌های قبلی و ایجاد یک pull request
- معرفی کردن یک راه حل برای پیاده‌سازی فیچرهای جدید
